<?php
/**
 * Admin backend for Settings
 *
 * @link       #
 * @since      1.5.0
 * @author     Woodpecker Team
 * @package    Woodpecker_For_Wordpress_Connector
 * @subpackage Woodpecker_For_Wordpress_Connector/admin/partials
 */

if (!defined('Woodpecker_For_Wordpress_Connector_Admin')) :
    die('Direct access not permitted');
endif;
?>

<form method="post" name="woodpecker-options">
  <div class="col-container">
    <div class="col-container__margin">
      <?php
        global $wpdb;

        $formData = $wpdb->get_row( "SELECT * FROM " . $wpdb->prefix . "wfw_forms WHERE id = 1");
        $fieldsData = $wpdb->get_results( "SELECT * FROM " . $wpdb->prefix . "wfw_forms_fields WHERE form_id = 1");

        $getconnectcampaign = new Woodpecker_For_Wordpress_Connector_Curl('/rest/v1/me', $formData->api_key);
        $getjsoncampaign = $getconnectcampaign->getJson();
        $getstatus = $getjsoncampaign->status;
        $error = false;

        if ($getstatus->status == 'ERROR' || $formData->api_key == '') :
          $error = true;
        endif;
      ?>

        <div class="settings-container">
          <div class="settings-container__menu">
            <ul>
              <li id="synchronization"><?php esc_attr_e('Synchronization', $this->plugin_name); ?></li>
              <li id="form-fields"><?php esc_attr_e('Form fields', $this->plugin_name); ?></li>
              <li id="form-styling"><?php esc_attr_e('Form styling', $this->plugin_name); ?></li>
              <li id="messages"><?php esc_attr_e('Messages', $this->plugin_name); ?></li>
              <li id="privacy-policy"><?php esc_attr_e('Privacy policy', $this->plugin_name); ?></li>
            </ul>
          </div>
          <div class="settings-container__content">
            <div id="synchronization-box" style="display: none;">
              <div>
                <label class="settings-container__content--label"><?php esc_attr_e('api key', $this->plugin_name); ?></label>
                <input type="text"
                  class="settings-container__content--input api <?php _e(($error == true ? "error" : "")); ?>"
                  id="<?php _e($this->plugin_name); ?>-api_key"
                  name="wfw-api_key"
                  placeholder="<?php _e('API key', $this->plugin_name); ?>"
                  value="<?php _e($formData->api_key); ?>"
                  autocomplete="off"/>

                <?php if ($error == true) : ?>
                  <span class="error"><?php esc_attr_e('The API key is incorrect or no longer valid. You can generate a new key in your Woodpecker account in "Settings".', $this->plugin_name); ?></span>
                <?php else: ?>
                  <span class="info"><?php esc_attr_e('Generate in Woodpecker Settings', $this->plugin_name); ?></span>
                <?php endif; ?>
              </div>
          </div>

          <div id="form-fields-box" style="display: none;">
            <div id="form-fields-container">
              <div class="settings-container__box header">
                <div class="field">Field label</div>
                <div class="field">Woodpecker field</div>
              </div>
              <?php
                $i = 1;
                foreach ($fieldsData as $key) {
                    $class = '';
                    $checked = 'checked';

                    if (!$key->field_state) {
                      $class = 'disable';
                      $checked = '';
                    }

                    echo '
                      <div class="settings-container__box ' . $class . '">
                        <div class="settings-container__content--box">
                          <input type="text"
                            class="settings-container__content--input"
                            id="woodpecker-field-' . $i . '"
                            name="woodpecker-field-' . $i . '"
                            value="' . $key->field_label . '"
                            placeholder="Field label..."
                            autocomplete="off"/>
                        </div>';

                  if (strtolower($key->fields_map) != 'email') {
                    echo '
                      <div class="settings-container__content--box">
                        <div class="dropdownWidget">
                          <span class="dropdownWidget__rows" onclick="openDropdown(this, \'1\');">' . str_replace("_", " ", ucfirst(strtolower($key->fields_map))) . '</span>
                          <div class="dropdownWidget__rows--block" style="display: none;">
                          <div class="dropdownWidget__scroll">
                            <span class="dropdownWidget__rows--block__value">First name</span>
                            <span class="dropdownWidget__rows--block__value">Last name</span>
                            <span class="dropdownWidget__rows--block__value">Company</span>
                            <span class="dropdownWidget__rows--block__value">Website</span>
                            <span class="dropdownWidget__rows--block__value">Title</span>
                            <span class="dropdownWidget__rows--block__value">Phone</span>
                            <span class="dropdownWidget__rows--block__value">Address</span>
                            <span class="dropdownWidget__rows--block__value">City</span>
                            <span class="dropdownWidget__rows--block__value">State</span>
                            <span class="dropdownWidget__rows--block__value">Country</span>
                            <span class="dropdownWidget__rows--block__value">Industry</span>
                            <span class="dropdownWidget__rows--block__value">Snippet 1</span>
                            <span class="dropdownWidget__rows--block__value">Snippet 2</span>
                            <span class="dropdownWidget__rows--block__value">Snippet 3</span>
                            <span class="dropdownWidget__rows--block__value">Snippet 4</span>
                            <span class="dropdownWidget__rows--block__value">Snippet 5</span>
                            <span class="dropdownWidget__rows--block__value">Snippet 6</span>
                            <span class="dropdownWidget__rows--block__value">Snippet 7</span>
                            <span class="dropdownWidget__rows--block__value">Snippet 8</span>
                            <span class="dropdownWidget__rows--block__value">Snippet 9</span>
                            <span class="dropdownWidget__rows--block__value">Snippet 10</span>
                            <span class="dropdownWidget__rows--block__value">Snippet 11</span>
                            <span class="dropdownWidget__rows--block__value">Snippet 12</span>
                            <span class="dropdownWidget__rows--block__value">Snippet 13</span>
                            <span class="dropdownWidget__rows--block__value">Snippet 14</span>
                            <span class="dropdownWidget__rows--block__value">Snippet 15</span>
                          </div>
                          </div>
                          <span id="dropdownWidget__error--' . $i . '" class="dropdownWidget__error">This Woodpecker field is already in use.</span>
                        </div>
                        <input type="hidden"
                          id="map-field-' . $i . '"
                          name="map-field-' . $i . '"
                          value="' . strtoupper($key->fields_map) . '"/>
                        </div>

                        <div class="settings-container__content--checkbox">
                          <input type="checkbox"
                            class="settings-container__content--checkbox__input"
                            id="state-field-' . $i . '"
                            name="state-field-' . $i . '"
                            value="1" ' . $checked . '/> Show
                          <span class="custom-checkbox"></span>
                        </div>
                        </div>
                    ';
                  } else {
                    echo '
                    <div class="settings-container__content--box disable">
                      <input type="text"
                        class="settings-container__content--input"
                        id="map-field-' . $i . '"
                        value="Email"
                        autocomplete="off" disabled/>
                    </div>
                    </div>';
                  }
                  $i++;
                }
              ?>
            </div>
            <?php
              $countData = count((array) $fieldsData);
              echo '<input id="wfw-count-fields" type="hidden" value="' . $countData . '"><span id="add-new-form" class="btn-link blue">Add new form field</span>';
            ?>
          </div>

          <div id="form-styling-box" style="display: none;">
              <div>
                <div class="settings-container__content--box">
                  <span class="settings-container__content--span"><?php esc_attr_e('Button label:', $this->plugin_name); ?></span>
                  <input type="text"
                      class="settings-container__content--input"
                      placeholder="<?php esc_attr_e('Button...', $this->plugin_name); ?>"
                      id="<?php _e($this->plugin_name); ?>-gform_submit"
                      name="wfw-button_label"
                      value="<?php _e($formData->button_label); ?>"
                      autocomplete="off"/>
                </div>
                <div class="settings-container__content--selector__box">
                  <span class="settings-container__content--selector__span"><?php esc_attr_e('Button style:', $this->plugin_name); ?></span>
                  <div class="wfw-switch">
                    <div class="switch-widget">
                      <div class="sw-cont">
                        <input type="checkbox"
                            id="<?php _e($this->plugin_name); ?>-gform_default_style"
                            name="wfw-default_style"
                            value="1" <?php checked((!isset($formData->default_style) ? 1 : $formData->default_style), 1); ?> />
                        <div class="sw-icon">
                          <div></div>
                        </div>
                        <div class="sw-label" style="display: none;" ></div>
                      </div>
                    </div>
                  </div>
                </div>
                <div id="picker-panel">
                  <div id="<?php _e($this->plugin_name); ?>-color_submit-box" class="settings-container__content--pickers__box">
                    <span class="settings-container__content--pickers__span"><?php esc_attr_e('Font color:', $this->plugin_name); ?></span>
                    <input type="text"
                        class="<?php _e($this->plugin_name); ?>-color-picker color-field"
                        id="<?php _e($this->plugin_name); ?>-color_submit"
                        name="wfw-font_color"
                        value="<?php _e($formData->font_color); ?>" />
                  </div>
                  <div id="<?php _e($this->plugin_name); ?>-color_submit_bg-box" class="settings-container__content--pickers__box">
                    <span class="settings-container__content--pickers__span"><?php esc_attr_e('Button color:', $this->plugin_name); ?></span>
                    <input type="text"
                        class="<?php _e($this->plugin_name); ?>-color-picker color-field"
                        id="<?php _e($this->plugin_name); ?>-color_submit_bg"
                        name="wfw-button_color"
                        value="<?php _e($formData->button_color); ?>" />
                  </div>
                  <div id="<?php _e($this->plugin_name); ?>-color_submit_b_-hover-box" class="settings-container__content--pickers__box">
                    <span class="settings-container__content--pickers__span"><?php esc_attr_e('Button hover:', $this->plugin_name); ?></span>
                    <input type="text"
                        class="<?php _e($this->plugin_name); ?>-color-picker color-field"
                        id="<?php _e($this->plugin_name); ?>-color_submit_b_-hover"
                        name="wfw-button_hover"
                        value="<?php _e($formData->button_hover); ?>" />
                  </div>
                </div>
              </div>
          </div>

          <div id="messages-box" style="display: none;">
            <div>
              <label class="settings-container__content--label"><?php esc_attr_e('success message', $this->plugin_name); ?></label>
              <div class="settings-container__content--scroll">
                  <textarea
                      class="settings-container__content--textarea"
                      id="<?php _e($this->plugin_name); ?>-message_success"
                      name="wfw-success_message"
                      autocomplete="off"><?php _e(stripslashes_deep($formData->success_message)); ?></textarea>
                </div>
                <label class="settings-container__content--label"><?php esc_attr_e('error message', $this->plugin_name); ?></label>
                <div class="settings-container__content--scroll">
                  <textarea
                      class="settings-container__content--textarea"
                      id="<?php _e($this->plugin_name); ?>-message_error"
                      name="wfw-error_message"
                      autocomplete="off"><?php _e(stripslashes_deep($formData->error_message)); ?></textarea>
                </div>
                <label class="settings-container__content--label"><?php esc_attr_e('\'email already exist\' message', $this->plugin_name); ?></label>
                <div class="settings-container__content--scroll">
                  <textarea
                    class="settings-container__content--textarea"
                    id="<?php _e($this->plugin_name); ?>-message_exist"
                    name="wfw-already_exist_message"
                    autocomplete="off"><?php _e(stripslashes_deep($formData->already_exist_message)); ?></textarea>
                </div>
              </div>
          </div>

          <div id="privacy-policy-box" style="display: none;">
            <div>
              <label class="settings-container__content--label"><?php esc_attr_e('privacy policy', $this->plugin_name); ?></label>
              <div class="settings-container__content--scroll">
                <textarea
                  class="settings-container__content--textarea"
                  id="<?php _e($this->plugin_name); ?>-privacy_policy"
                  name="wfw-privacy_policy_message"
                  autocomplete="off"><?php _e(stripslashes_deep($formData->privacy_policy_message)); ?></textarea>
              </div>
              <span class="info"><?php esc_attr_e('You can add a privacy policy link by using HTML attribute', $this->plugin_name); ?></span>
            </div>
          </div>
          <input type="hidden" value=""  id="box-name" name="<?php _e($this->plugin_name); ?>[box_name]">
          <input type="hidden" value=""  id="new-fields" name="new-fields">
          <div class="settings-container__footer">
            <div id="sticky-footer" class="save-box fixed">
              <input type="submit" name="wfw-submit" class="button btn-woodpecker" value="<?php _e('Save', $this->plugin_name); ?>">
              <span class="save-box__close"></span>
            </div>
          </div>
      </div>
    </div>
  </div>
</div>
</form>
<script type="text/javascript" src="<?php _e(plugin_dir_url( __FILE__ )); ?>../js/wfw-settings.min.js?ver=2.1"></script>
<script type="text/javascript" src="<?php _e(plugin_dir_url( __FILE__ )); ?>../js/slimscroll.min.js"></script>
