<?php
/**
 * The plugin Woodpecker for WordPress
 *
 * @link              #
 * @since             1.0.0
 * @package           Woodpecker_For_Wordpress_Connector
 *
 * @wordpress-plugin
 * Plugin Name:       Woodpecker
 * Plugin URI:        https://woodpecker.co/plugins/wordpress-leadform/
 * Description:       Add Woodpecker for WordPress to your Wordpress and enjoy automatic transfer of data from the Woodpecker for WordPress into your Woodpecker campaign. Never lose a lead again.
 * Version:           1.5.0
 * Author:            Woodpecker.co
 * Author URI:        https://woodpecker.co
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       wfw
 * Domain Path:       /languages
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

define( 'WOODPECKER_PLUGIN_NAME_VERSION', '1.5.0' );
define( 'WOODPECKER_PLUGIN_URL', plugin_dir_url( __FILE__ ) );

function activate_woodpecker_for_wordpress() {
	global $wpdb;

	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	$installed_version = get_option('wfw_db_version');

	$formsData = $wpdb->get_row("SELECT * FROM " . $wpdb->prefix . "wfw_forms WHERE id = 1");

	$sql = "CREATE TABLE IF NOT EXISTS " . $wpdb->prefix . "wfw_forms_fields (
				id INT NOT NULL auto_increment,
				field_label varchar(255) NOT NULL,
				field_state BOOLEAN DEFAULT true NOT NULL,
				fields_map varchar(255) NOT NULL,
				form_id INT NOT NULL,
				timestamp DATETIME,
				PRIMARY KEY (id)
			) ". $charset_collate .";";

	dbDelta( $sql );

	if ($installed_version != WOODPECKER_PLUGIN_NAME_VERSION) {
		if (!empty($formsData)) {

			$isFirstNameShow = false;
			$isLastNameShow = false;
			$isCompanyShow = false;

			if ($formsData->first_name_hide == '1') {
				$isFirstNameShow = true;
			}

			if ($formsData->last_name_hide == '1') {
				$isLastNameShow = true;
			}

			if ($formsData->company_hide == '1') {
				$isCompanyShow = true;
			}

			$emailData = array(
					'id' => '',
					'field_label' => sanitize_text_field($formsData->email_label),
					'field_state' => true,
					'fields_map' => 'EMAIL',
					'form_id' => 1,
					'timestamp' => date('Y-m-d H:m:s'),
			);
			$wpdb->insert($wpdb->prefix . 'wfw_forms_fields', $emailData);

			$firstNameData = array(
					'id' => '',
					'field_label' => sanitize_text_field($formsData->first_name_label),
					'field_state' => sanitize_key($isFirstNameShow),
					'fields_map' => 'FIRST_NAME',
					'form_id' => 1,
					'timestamp' => date('Y-m-d H:m:s'),
			);
			$wpdb->insert($wpdb->prefix . 'wfw_forms_fields', $firstNameData);

			$lastNameData = array(
					'id' => '',
					'field_label' => sanitize_text_field($formsData->last_name_label),
					'field_state' => sanitize_key($isLastNameShow),
					'fields_map' => 'LAST_NAME',
					'form_id' => 1,
					'timestamp' => date('Y-m-d H:m:s'),
			);
			$wpdb->insert($wpdb->prefix . 'wfw_forms_fields', $lastNameData);

			$companyData = array(
					'id' => '',
					'field_label' => sanitize_text_field($formsData->company_label),
					'field_state' => sanitize_key($isCompanyShow),
					'fields_map' => 'COMPANY',
					'form_id' => 1,
					'timestamp' => date('Y-m-d H:m:s'),
			);
			$wpdb->insert($wpdb->prefix . 'wfw_forms_fields', $companyData);

			$wpdb->query("ALTER TABLE " . $wpdb->prefix . "wfw_forms
				DROP COLUMN email_label,
				DROP COLUMN email_hide,
				DROP COLUMN first_name_label,
				DROP COLUMN first_name_hide,
				DROP COLUMN last_name_label,
				DROP COLUMN last_name_hide,
				DROP COLUMN company_label,
				DROP COLUMN company_hide;
			");
		}
	}

	$formsFieldsData = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "wfw_forms_fields");

	if (empty($formsFieldsData)) {
		$defaultField = array(
				'id' => '',
				'field_label' => 'Email',
				'field_state' => true,
				'fields_map' => 'EMAIL',
				'form_id' => 1,
				'timestamp' => date('Y-m-d H:m:s'),
		);
		$wpdb->insert($wpdb->prefix . 'wfw_forms_fields', $defaultField);
	}

	$sql = "CREATE TABLE IF NOT EXISTS " . $wpdb->prefix . "wfw_forms (
				id INT NOT NULL auto_increment,
				create_date DATE,
				last_mod_date DATE,
				button_label varchar(255) NOT NULL,
				default_style int(1) DEFAULT '1' NOT NULL,
				font_color varchar(255) DEFAULT '#000000' NOT NULL,
				button_color varchar(255) DEFAULT '#000000' NOT NULL,
				button_hover varchar(255) DEFAULT '#000000' NOT NULL,
				success_message text,
				error_message text,
				already_exist_message text,
				privacy_policy_message text,
				api_key text,

				PRIMARY KEY  (id)
			) ". $charset_collate .";";

	dbDelta($sql);

	if (empty($formsData)) {
		$data = array(
					'id' => '',
					'create_date' => date("Y-m-d"),
					'last_mod_date' => "",
					'button_label' => 'Submit',
					'default_style' => 1,
					'font_color' => '#FFF',
					'button_color' => '#5d32e9',
					'button_hover' => '#5d32e9',
					'success_message' => '<p>Subscription complete</p>',
					'error_message' => '<p>You need to fill all labels to submit your form.</p>',
					'already_exist_message' => '<p>You have already subscribed. Your data has been updated.</p>',
					'privacy_policy_message' => '<p>Accept Privacy Policy</p>',
					'api_key' => '',
				);
		$wpdb->insert($wpdb->prefix . 'wfw_forms', $data);
	}

	update_option('wfw_db_version', WOODPECKER_PLUGIN_NAME_VERSION);
}

register_activation_hook( __FILE__, 'activate_woodpecker_for_wordpress' );

require plugin_dir_path( __FILE__ ) . 'includes/class-wfw.php';


/**
 * @since    1.0.0
 */
function run_woodpecker_for_wordpress() {
	$plugin = new Woodpecker_For_Wordpress_Connector();
	$plugin->run();
}
run_woodpecker_for_wordpress();


/**
 * Link to settings
 * @since    1.0.3
 */
add_filter( 'plugin_action_links_' . plugin_basename(__FILE__), 'add_action_links' );

function add_action_links( $links ) {
	$settings_link = array(
		'<a href="' . admin_url( 'admin.php?page=wfw') . '">' . __('Settings', 'wfw') . '</a>',
	);
	return array_merge($links, $settings_link);
}
